@@ -18,9 +18,10 @@ import subprocess
 import time
 import signal as signal_module
 
-from robot.utils import (ConnectionCache, abspath, encode_to_system,
-                         decode_output, is_truthy, secs_to_timestr,
-                         timestr_to_secs, IRONPYTHON, JYTHON)
+from robot.utils import (ConnectionCache, abspath, cmdline2list,
+                         encode_to_system, decode_output, is_list_like,
+                         is_truthy, secs_to_timestr, timestr_to_secs,
+                         IRONPYTHON, JYTHON)
 from robot.version import get_version
 from robot.api import logger
 
@@ -352,16 +353,15 @@ class Process(object):
         Jython in general nor by Python versions prior to 2.7 on Windows.
         """
         config = ProcessConfig(**configuration)
-        executable_command = self._cmd(command, arguments, config.shell)
-        logger.info('Starting process:\n%s' % executable_command)
-        logger.debug('Process configuration:\n%s' % config)
-        process = subprocess.Popen(executable_command, **config.full_config)
+        command = self._get_command(command, arguments, config.shell)
+        self._log_start(command, config)
+        process = subprocess.Popen(command, **config.full_config)
         self._results[process] = ExecutionResult(process,
                                                  config.stdout_stream,
                                                  config.stderr_stream)
         return self._processes.register(process, alias=config.alias)
 
-    def _cmd(self, command, args, use_shell):
+    def _get_command(self, command, args, use_shell):
         command = [encode_to_system(item) for item in [command] + list(args)]
         if not use_shell:
             return command
@@ -369,6 +369,12 @@ class Process(object):
             return subprocess.list2cmdline(command)
         return command[0]
 
+    def _log_start(self, command, config):
+        if is_list_like(command):
+            command = self.join_command_line(command)
+        logger.info('Starting process:\n%s' % command)
+        logger.debug('Process configuration:\n%s' % config)
+
     def is_process_running(self, handle=None):
         """Checks is the process running or not.
 
@@ -725,6 +731,43 @@ class Process(object):
             time.sleep(min(0.1, timeout))
         return stopped()
 
+    def split_command_line(self, args, escaping=False):
+        """Splits command line string into a list of arguments.
+
+        String is split from spaces, but argument surrounded in quotes may
+        contain spaces in them. If ``escaping`` is given a true value, then
+        backslash is treated as an escape character. It can escape unquoted
+        spaces, quotes inside quotes, and so on, but it also requires using
+        double backslashes when using Windows paths.
+
+        Examples:
+        | @{cmd} = | Split Command Line | --option "value with spaces" |
+        | Should Be True | $cmd == ['--option', 'value with spaces'] |
+
+        New in Robot Framework 2.9.2.
+        """
+        return cmdline2list(args, escaping=escaping)
+
+    def join_command_line(self, *args):
+        """Joins arguments into one command line string.
+
+        In resulting command line string arguments are delimited with a space,
+        arguments containing spaces are surrounded with quotes, and possible
+        quotes are escaped with a backslash.
+
+        If this keyword is given only one argument and that is a list like
+        object, then the values of that list are joined instead.
+
+        Example:
+        | ${cmd} = | Join Command Line | --option | value with spaces |
+        | Should Be Equal | ${cmd} | --option "value with spaces" |
+
+        New in Robot Framework 2.9.2.
+        """
+        if len(args) == 1 and is_list_like(args[0]):
+            args = args[0]
+        return subprocess.list2cmdline(args)
+
 
 class ExecutionResult(object):
 
