@@ -14,6 +14,7 @@
 
 import copy
 import re
+import os
 
 try:
     from lxml import etree as lxml_etree
@@ -50,16 +51,10 @@ class XML(object):
     - Modifying XML and saving it (e.g. `Set Element Text`, `Add Element`
       and `Save XML`).
 
-    By default this library uses ElementTree module for parsing XML, but it
-    can be configured to use [http://lxml.de|lxml] instead when `importing`
-    the library. The main benefit of using lxml is that it supports richer
-    xpath syntax than the standard ElementTree. It also enables using
-    `Evaluate Xpath` keyword and preserves possible namespace prefixes when
-    saving XML. The lxml support is new in Robot Framework 2.8.5.
-
     == Table of contents ==
 
     - `Parsing XML`
+    - `Using lxml`
     - `Example`
     - `Finding elements with xpath`
     - `Element attributes`
@@ -73,7 +68,14 @@ class XML(object):
     XML can be parsed into an element structure using `Parse XML` keyword.
     It accepts both paths to XML files and strings that contain XML. The
     keyword returns the root element of the structure, which then contains
-    other elements as its children and their children.
+    other elements as its children and their children. Possible comments and
+    processing instructions in the source XML are removed.
+
+    XML is not validated during parsing even if has a schema defined. How
+    possible doctype elements are handled otherwise depends on the used XML
+    module and on the platform. The standard ElementTree strips doctypes
+    altogether but when `using lxml` they are preserved when XML is saved.
+    With IronPython parsing XML with a doctype is not supported at all.
 
     The element structure returned by `Parse XML`, as well as elements
     returned by keywords such as `Get Element`, can be used as the ``source``
@@ -81,7 +83,7 @@ class XML(object):
     structure, other keywords also accept paths to XML files and strings
     containing XML similarly as `Parse XML`. Notice that keywords that modify
     XML do not write those changes back to disk even if the source would be
-    given as a path to a fike. Changes must always saved explicitly using
+    given as a path to a file. Changes must always saved explicitly using
     `Save XML` keyword.
 
     When the source is given as a path to a file, the forward slash character
@@ -90,6 +92,21 @@ class XML(object):
     escaped by doubling it (``\\\\``). Using the built-in variable ``${/}``
     naturally works too.
 
+    = Using lxml =
+
+    By default this library uses Python's standard
+    [https://docs.python.org/2/library/xml.etree.elementtree.html|ElementTree]
+    module for parsing XML, but it can be configured to use
+    [http://lxml.de|lxml] module instead when `importing` the library.
+    The resulting element structure has same API regardless which module
+    is used for parsing.
+
+    The main benefits of using lxml is that it supports richer xpath syntax
+    than the standard ElementTree and enables using `Evaluate Xpath` keyword.
+    It also preserves the doctype and possible namespace prefixes saving XML.
+
+    The lxml support is new in Robot Framework 2.8.5.
+
     = Example =
 
     The following simple example demonstrates parsing XML and verifying its
@@ -365,11 +382,11 @@ class XML(object):
     Also this output is semantically same as the original. If the original XML
     had only default namespaces, the output would also look identical.
 
-    == Namespaces with lxml ==
+    == Namespaces when using lxml ==
 
-    Namespaces are handled the same way also if lxml mode is enabled when
-    `importing` the library. The only difference is that lxml stores information
-    about namespace prefixes and thus they are preserved if XML is saved.
+    Namespaces are handled the same way also when `using lxml`. The only
+    difference is that lxml stores information about namespace prefixes and
+    thus they are preserved if XML is saved.
 
     == Attribute namespaces ==
 
@@ -416,7 +433,7 @@ class XML(object):
     ROBOT_LIBRARY_SCOPE = 'GLOBAL'
     ROBOT_LIBRARY_VERSION = get_version()
     _whitespace = re.compile('\s+')
-    _xml_declaration = re.compile('^<\?xml .*\?>\n')
+    _xml_declaration = re.compile('^<\?xml .*\?>')
 
     def __init__(self, use_lxml=False):
         """Import library with optionally lxml mode enabled.
@@ -425,7 +442,7 @@ class XML(object):
         [https://docs.python.org/2/library/xml.etree.elementtree.html|ElementTree]
         module for parsing XML. If ``use_lxml`` argument is given a true value
         (see `Boolean arguments`), the library will use [http://lxml.de|lxml]
-        instead. See `introduction` for benefits provided by lxml.
+        module instead. See `Using lxml` section for benefits provided by lxml.
 
         Using lxml requires that the lxml module is installed on the system.
         If lxml mode is enabled but the module is not installed, this library
@@ -452,7 +469,8 @@ class XML(object):
         The ``source`` can either be a path to an XML file or a string
         containing XML. In both cases the XML is parsed into ElementTree
         [http://docs.python.org/library/xml.etree.elementtree.html#xml.etree.ElementTree.Element|element structure]
-        and the root element is returned.
+        and the root element is returned. Possible comments and processing
+        instructions in the source XML are removed.
 
         As discussed in `Handling XML namespaces` section, this keyword, by
         default, strips possible namespaces added by ElementTree into tag names.
@@ -473,20 +491,15 @@ class XML(object):
         Stripping namespaces is a new feature in Robot Framework 2.7.5.
         """
         with ETSource(source) as source:
-            root = self.etree.parse(source).getroot()
+            tree = self.etree.parse(source)
         if self.lxml_etree:
-            self._remove_comments(root)
+            strip = (lxml_etree.Comment, lxml_etree.ProcessingInstruction)
+            lxml_etree.strip_elements(tree, *strip, **dict(with_tail=False))
+        root = tree.getroot()
         if not is_truthy(keep_clark_notation):
             NameSpaceStripper().strip(root)
         return root
 
-    def _remove_comments(self, node):
-        for comment in node.xpath('//comment()'):
-            parent = comment.getparent()
-            if parent:
-                self._preserve_tail(comment, parent)
-                parent.remove(comment)
-
     def get_element(self, source, xpath='.'):
         """Returns an element in the ``source`` matching the ``xpath``.
 
@@ -1278,20 +1291,25 @@ class XML(object):
         """
         return copy.deepcopy(self.get_element(source, xpath))
 
-    def element_to_string(self, source, xpath='.'):
+    def element_to_string(self, source, xpath='.', encoding=None):
         """Returns the string representation of the specified element.
 
         The element to convert to a string is specified using ``source`` and
         ``xpath``. They have exactly the same semantics as with `Get Element`
         keyword.
 
-        The returned string is in Unicode format and it does not contain any
-        XML declaration.
+        By default the string is returned as Unicode. If ``encoding`` argument
+        is given any value, the string is returned as bytes in the specified
+        encoding. The resulting string never contains the XML declaration.
 
         See also `Log Element` and `Save XML`.
         """
-        string = self.etree.tostring(self.get_element(source, xpath), encoding='UTF-8')
-        return self._xml_declaration.sub('', string.decode('UTF-8')).strip()
+        source = self.get_element(source, xpath)
+        string = self.etree.tostring(source, encoding='UTF-8').decode('UTF-8')
+        string = self._xml_declaration.sub('', string).strip()
+        if encoding:
+            string = string.encode(encoding)
+        return string
 
     def log_element(self, source, level='INFO', xpath='.'):
         """Logs the string representation of the specified element.
@@ -1313,14 +1331,22 @@ class XML(object):
         semantics as with `Get Element` keyword.
 
         The file where the element is saved is denoted with ``path`` and the
-        encoding to use with ``encoding``. The resulting file contains an XML
-        declaration.
+        encoding to use with ``encoding``. The resulting file always contains
+        the XML declaration.
+
+        The resulting XML file may not be exactly the same as the original:
+        - Comments and processing instructions are always stripped.
+        - Possible doctype and namespace prefixes are only preserved when
+          `using lxml`.
+        - Other small differences are possible depending on the ElementTree
+          or lxml version.
 
         Use `Element To String` if you just need a string representation of
-        the element,
+        the element.
 
         New in Robot Framework 2.7.5.
         """
+        path = os.path.abspath(path.replace('/', os.sep))
         elem = self.get_element(source)
         if self.lxml_etree:
             NameSpaceStripper().unstrip(elem)
@@ -1330,6 +1356,8 @@ class XML(object):
         # close files they open and Jython/IPY don't close them implicitly.
         with open(path, 'w') as output:
             tree.write(output, encoding=encoding, **xml_declaration)
+        logger.info('XML saved to <a href="file://%s">%s</a>.' % (path, path),
+                    html=True)
 
     def evaluate_xpath(self, source, expression, context='.'):
         """Evaluates the given xpath expression and returns results.
