@@ -1,4 +1,4 @@
-#  Copyright 2008-2014 Nokia Solutions and Networks
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -26,17 +26,17 @@ class TestCase(ModelObject):
     keyword_class = Keyword
 
     def __init__(self, name='', doc='', tags=None, timeout=None):
-        #: :class:`~.testsuite.TestSuite` that contains this test.
+        #: :class:`~.model.testsuite.TestSuite` that contains this test.
         self.parent = None
         #: Test case name.
         self.name = name
         #: Test case documentation.
         self.doc = doc
-        #: Test case tags, a list of strings.
+        #: Test case tags as a list like :class:`~.model.tags.Tags` object.
         self.tags = tags
         #: Test case timeout.
         self.timeout = timeout
-        #: Keyword results, a list of :class:`~.keyword.Keyword`
+        #: Keyword results, a list of :class:`~.model.keyword.Keyword`
         #: instances and contains also possible setup and teardown keywords.
         self.keywords = None
 
@@ -70,7 +70,8 @@ class TestCases(ItemList):
     def __init__(self, test_class=TestCase, parent=None, tests=None):
         ItemList.__init__(self, test_class, {'parent': parent}, tests)
 
-    def _check_type_and_set_attrs(self, test):
-        ItemList._check_type_and_set_attrs(self, test)
-        for visitor in test.parent._visitors:
-            test.visit(visitor)
+    def _check_type_and_set_attrs(self, *tests):
+        ItemList._check_type_and_set_attrs(self, *tests)
+        for test in tests:
+            for visitor in test.parent._visitors:
+                test.visit(visitor)
