@@ -1,4 +1,4 @@
-#  Copyright 2008-2014 Nokia Solutions and Networks
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,15 +12,15 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from robot import utils
 from robot.errors import DataError
 from robot.model import Message as BaseMessage
+from robot.utils import get_timestamp, is_unicode, unic
 
 
 LEVELS = {
   'NONE'  : 6,
-  'ERROR' : 5,
-  'FAIL'  : 4,
+  'FAIL'  : 5,
+  'ERROR' : 4,
   'WARN'  : 3,
   'INFO'  : 2,
   'DEBUG' : 1,
@@ -71,14 +71,14 @@ class Message(BaseMessage):
     def __init__(self, message, level='INFO', html=False, timestamp=None):
         message = self._normalize_message(message)
         level, html = self._get_level_and_html(level, html)
-        timestamp = timestamp or utils.get_timestamp()
+        timestamp = timestamp or get_timestamp()
         BaseMessage.__init__(self, message, level, html, timestamp)
 
     def _normalize_message(self, msg):
         if callable(msg):
             return msg
-        if not isinstance(msg, unicode):
-            msg = utils.unic(msg)
+        if not is_unicode(msg):
+            msg = unic(msg)
         if '\r\n' in msg:
             msg = msg.replace('\r\n', '\n')
         return msg
@@ -88,19 +88,19 @@ class Message(BaseMessage):
         if level == 'HTML':
             return 'INFO', True
         if level not in LEVELS:
-            raise DataError("Invalid log level '%s'" % level)
+            raise DataError("Invalid log level '%s'." % level)
         return level, html
 
-    def _get_message(self):
+    @property
+    def message(self):
         if callable(self._message):
             self._message = self._message()
         return self._message
 
-    def _set_message(self, message):
+    @message.setter
+    def message(self, message):
         self._message = message
 
-    message = property(_get_message, _set_message)
-
 
 class IsLogged:
 
@@ -120,7 +120,7 @@ class IsLogged:
         try:
             return LEVELS[level.upper()]
         except KeyError:
-            raise DataError("Invalid log level '%s'" % level)
+            raise DataError("Invalid log level '%s'." % level)
 
 
 class AbstractLoggerProxy:
@@ -133,9 +133,13 @@ class AbstractLoggerProxy:
             setattr(self, name, self._get_method(logger, name))
 
     def _get_method(self, logger, name):
-        if hasattr(logger, name):
-            return getattr(logger, name)
-        return getattr(logger, self._toCamelCase(name), self._no_method)
+        for method_name in self._get_method_names(name):
+            if hasattr(logger, method_name):
+                return getattr(logger, method_name)
+        return self._no_method
+
+    def _get_method_names(self, name):
+        return [name, self._toCamelCase(name)]
 
     def _toCamelCase(self, name):
         parts = name.split('_')
