@@ -1,4 +1,4 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
 from java.lang import Byte, Short, Integer, Long, Boolean, Float, Double
 
 from robot.variables import contains_var
-from robot.utils import is_list_like
+from robot.utils import is_string, is_list_like
 
 
 class JavaArgumentCoercer(object):
@@ -76,7 +76,7 @@ class _Coercer(object):
         return type in self._types or type.__name__ in self._primitives
 
     def coerce(self, argument, dryrun=False):
-        if not isinstance(argument, basestring) \
+        if not is_string(argument) \
                 or (dryrun and contains_var(argument)):
             return argument
         try:
