@@ -61,7 +61,6 @@ class _ExecutionContext(object):
         self.in_keyword_teardown = 0
         self._started_keywords = 0
         self.timeout_occurred = False
-        self.failure_in_test_teardown = False
 
     # TODO: namespace should not have suite, test, or uk_handlers.
 
@@ -94,7 +93,6 @@ class _ExecutionContext(object):
             yield
         finally:
             self.in_test_teardown = False
-            self.failure_in_test_teardown = False
 
     @contextmanager
     def keyword_teardown(self, error):
@@ -169,8 +167,6 @@ class _ExecutionContext(object):
     def end_keyword(self, keyword):
         self.output.end_keyword(keyword)
         self._started_keywords -= 1
-        if self.in_test_teardown and not keyword.passed:
-            self.failure_in_test_teardown = True
 
     def get_handler(self, name):
         return self.namespace.get_handler(name)
