@@ -1,4 +1,4 @@
-#  Copyright 2008-2014 Nokia Solutions and Networks
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,62 +12,98 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from robot.errors import PassExecution
+from robot.errors import ExecutionFailed, PassExecution
+
+
+class Failure(object):
+
+    def __init__(self):
+        self.setup = None
+        self.test = None
+        self.teardown = None
+
+    def __nonzero__(self):
+        return bool(self.setup or self.test or self.teardown)
+
+
+class Exit(object):
+
+    def __init__(self, failure_mode=False, error_mode=False,
+                 skip_teardown_mode=False):
+        self.failure_mode = failure_mode
+        self.error_mode = error_mode
+        self.skip_teardown_mode = skip_teardown_mode
+        self.failure = False
+        self.error = False
+        self.fatal = False
+
+    def failure_occurred(self, failure=None, critical=False):
+        if isinstance(failure, ExecutionFailed) and failure.exit:
+            self.fatal = True
+        if critical and self.failure_mode:
+            self.failure = True
+
+    def error_occurred(self):
+        if self.error_mode:
+            self.error = True
+
+    @property
+    def teardown_allowed(self):
+        return not (self.skip_teardown_mode and self)
+
+    def __nonzero__(self):
+        return self.failure or self.error or self.fatal
 
 
 class _ExecutionStatus(object):
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, *exit_modes):
         self.parent = parent
-        self.setup_failure = None
-        self.test_failure = None
-        self.teardown_failure = None
+        self.children = []
+        self.failure = Failure()
+        self.exit = parent.exit if parent else Exit(*exit_modes)
         self._teardown_allowed = False
-        self.exiting_on_failure = parent.exiting_on_failure if parent else False
-        self.exiting_on_fatal = parent.exiting_on_fatal if parent else False
-        self.skip_teardown_on_exit_mode = parent.skip_teardown_on_exit_mode if parent else False
+        if parent:
+            parent.children.append(self)
 
     def setup_executed(self, failure=None):
         if failure and not isinstance(failure, PassExecution):
-            self.setup_failure = unicode(failure)
-            self._handle_possible_fatal(failure)
+            self.failure.setup = unicode(failure)
+            self.exit.failure_occurred(failure)
         self._teardown_allowed = True
 
     def teardown_executed(self, failure=None):
         if failure and not isinstance(failure, PassExecution):
-            self.teardown_failure = unicode(failure)
-            self._handle_possible_fatal(failure)
+            self.failure.teardown = unicode(failure)
+            self.exit.failure_occurred(failure)
+
+    def critical_failure_occurred(self):
+        self.exit.failure_occurred(critical=True)
+
+    def error_occurred(self):
+        self.exit.error_occurred()
 
     @property
     def teardown_allowed(self):
-        if self.skip_teardown_on_exit_mode and (self.exiting_on_failure or
-                                                self.exiting_on_fatal):
-            return False
-        return self._teardown_allowed
+        return self.exit.teardown_allowed and self._teardown_allowed
 
     @property
     def failures(self):
-        return bool(self._parent_failures() or self._my_failures())
+        return bool(self.parent and self.parent.failures or
+                    self.failure or self.exit)
 
     def _parent_failures(self):
         return self.parent and self.parent.failures
 
-    def _my_failures(self):
-        return bool(self.setup_failure or
-                    self.teardown_failure or
-                    self.test_failure or
-                    self.exiting_on_failure or
-                    self.exiting_on_fatal)
-
     @property
     def status(self):
         return 'FAIL' if self.failures else 'PASS'
 
     @property
     def message(self):
-        if self._my_failures():
+        if self.failure or self.exit:
             return self._my_message()
-        if self._parent_failures():
+        if self.parent and self.parent.failures:
             return self._parent_message()
         return ''
 
@@ -77,31 +113,15 @@ class _ExecutionStatus(object):
     def _parent_message(self):
         return ParentMessage(self.parent).message
 
-    def _handle_possible_fatal(self, failure):
-        if getattr(failure, 'exit', False):
-            if self.parent:
-                self.parent.fatal_failure()
-            self.exiting_on_fatal = True
-
 
 class SuiteStatus(_ExecutionStatus):
 
-    def __init__(self, parent, exit_on_failure_mode=False,
+    def __init__(self, parent=None, exit_on_failure_mode=False,
+                 exit_on_error_mode=False,
                  skip_teardown_on_exit_mode=False):
-        _ExecutionStatus.__init__(self, parent)
-        self.exit_on_failure_mode = exit_on_failure_mode
-        self.skip_teardown_on_exit_mode = skip_teardown_on_exit_mode
-
-    def critical_failure(self):
-        if self.exit_on_failure_mode:
-            self.exiting_on_failure = True
-        if self.parent:
-            self.parent.critical_failure()
-
-    def fatal_failure(self):
-        self.exiting_on_fatal = True
-        if self.parent:
-            self.parent.fatal_failure()
+        _ExecutionStatus.__init__(self, parent, exit_on_failure_mode,
+                                  exit_on_error_mode,
+                                  skip_teardown_on_exit_mode)
 
     def _my_message(self):
         return SuiteMessage(self).message
@@ -109,15 +129,14 @@ class SuiteStatus(_ExecutionStatus):
 
 class TestStatus(_ExecutionStatus):
 
-    def __init__(self, suite_status):
-        _ExecutionStatus.__init__(self, suite_status)
+    def __init__(self, parent, critical):
+        _ExecutionStatus.__init__(self, parent)
+        self.exit = parent.exit
+        self._critical = critical
 
-    def test_failed(self, failure, critical):
-        self.test_failure = unicode(failure)
-        if critical:
-            self.parent.critical_failure()
-            self.exiting_on_failure = self.parent.exit_on_failure_mode
-        self._handle_possible_fatal(failure)
+    def test_failed(self, failure):
+        self.failure.test = unicode(failure)
+        self.exit.failure_occurred(failure, self._critical)
 
     def _my_message(self):
         return TestMessage(self).message
@@ -129,9 +148,7 @@ class _Message(object):
     also_teardown_message = NotImplemented
 
     def __init__(self, status):
-        self.setup_failure = status.setup_failure
-        self.test_failure = status.test_failure or ''
-        self.teardown_failure = status.teardown_failure
+        self.failure = status.failure
 
     @property
     def message(self):
@@ -139,16 +156,16 @@ class _Message(object):
         return self._get_message_after_teardown(msg)
 
     def _get_message_before_teardown(self):
-        if self.setup_failure:
-            return self.setup_message % self.setup_failure
-        return self.test_failure
+        if self.failure.setup:
+            return self.setup_message % self.failure.setup
+        return self.failure.test or ''
 
     def _get_message_after_teardown(self, msg):
-        if not self.teardown_failure:
+        if not self.failure.teardown:
             return msg
         if not msg:
-            return self.teardown_message % self.teardown_failure
-        return self.also_teardown_message % (msg, self.teardown_failure)
+            return self.teardown_message % self.failure.teardown
+        return self.also_teardown_message % (msg, self.failure.teardown)
 
 
 class TestMessage(_Message):
@@ -158,21 +175,23 @@ class TestMessage(_Message):
     exit_on_fatal_message = 'Test execution stopped due to a fatal error.'
     exit_on_failure_message = \
         'Critical failure occurred and exit-on-failure mode is in use.'
+    exit_on_error_message = 'Error occurred and exit-on-error mode is in use.'
 
     def __init__(self, status):
         _Message.__init__(self, status)
-        self.exiting_on_failure = status.exiting_on_failure
-        self.exiting_on_fatal = status.exiting_on_fatal
+        self.exit = status.exit
 
     @property
     def message(self):
         message = super(TestMessage, self).message
         if message:
             return message
-        if self.exiting_on_failure:
+        if self.exit.failure:
             return self.exit_on_failure_message
-        if self.exiting_on_fatal:
+        if self.exit.fatal:
             return self.exit_on_fatal_message
+        if self.exit.error:
+            return self.exit_on_error_message
         return ''
 
 
