@@ -332,10 +332,7 @@ class _HybridLibrary(_BaseTestLibrary):
     _failure_level = 'ERROR'
 
     def _get_handler_names(self, instance):
-        try:
-            return instance.get_keyword_names()
-        except AttributeError:
-            return instance.getKeywordNames()
+        return GetKeywordNames(instance)()
 
 
 class _DynamicLibrary(_BaseTestLibrary):
