@@ -15,6 +15,7 @@
 import getopt     # optparse was not supported by Jython 2.2
 import os
 import re
+import shlex
 import sys
 import glob
 import string
@@ -26,7 +27,7 @@ from robot.version import get_full_version
 from .misc import plural_or_not
 from .encoding import decode_output, decode_from_system
 from .utf8reader import Utf8Reader
-from .robottypes import is_integer, is_list_like, is_string
+from .robottypes import is_falsy, is_integer, is_list_like, is_string, is_unicode
 
 
 ESCAPES = dict(
@@ -38,6 +39,24 @@ ESCAPES = dict(
 )
 
 
+def cmdline2list(args, escaping=False):
+    if is_unicode(args):
+        args = args.encode('UTF-8')
+        decode = lambda item: item.decode('UTF-8')
+    else:
+        decode = lambda item: item
+    lexer = shlex.shlex(args, posix=True)
+    if is_falsy(escaping):
+        lexer.escape = ''
+    lexer.escapedquotes = '"\''
+    lexer.commenters = ''
+    lexer.whitespace_split = True
+    try:
+        return [decode(token) for token in lexer]
+    except ValueError as err:
+        raise ValueError("Parsing '%s' failed: %s" % (args, err))
+
+
 class ArgumentParser(object):
     _opt_line_re = re.compile('''
     ^\s{1,4}      # 1-4 spaces in the beginning of the line
@@ -123,7 +142,7 @@ class ArgumentParser(object):
         are wrapped to Information exception.
         """
         if self._env_options:
-            args = os.getenv(self._env_options, '').split() + list(args)
+            args = cmdline2list(os.getenv(self._env_options, '')) + list(args)
         args = [decode_from_system(a) for a in args]
         if self._auto_argumentfile:
             args = self._process_possible_argfile(args)
@@ -351,11 +370,11 @@ class ArgLimitValidator(object):
 
     def _parse_arg_limits(self, arg_limits):
         if arg_limits is None:
-            return 0, sys.maxint
+            return 0, sys.maxsize
         if is_integer(arg_limits):
             return arg_limits, arg_limits
         if len(arg_limits) == 1:
-            return arg_limits[0], sys.maxint
+            return arg_limits[0], sys.maxsize
         return arg_limits[0], arg_limits[1]
 
     def __call__(self, args):
@@ -366,7 +385,7 @@ class ArgLimitValidator(object):
         min_end = plural_or_not(min_args)
         if min_args == max_args:
             expectation = "%d argument%s" % (min_args, min_end)
-        elif max_args != sys.maxint:
+        elif max_args != sys.maxsize:
             expectation = "%d to %d arguments" % (min_args, max_args)
         else:
             expectation = "at least %d argument%s" % (min_args, min_end)
