@@ -1,4 +1,4 @@
-#  Copyright 2008-2014 Nokia Solutions and Networks
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,7 +12,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import with_statement
 import os
 
 from robot.errors import DataError
@@ -25,8 +24,7 @@ class DataFileWriter(object):
 
     def __init__(self, **options):
         """
-        :param `**options`: A :class:`.WritingContext` is created based
-            on these.
+        :param `**options`: A :class:`.WritingContext` is created based on these.
         """
         self._options = options
 
